pub trait ShellProcess {
// Required methods
fn check_is_alive(&mut self) -> Result<()>;
fn terminate(self) -> Result<()>;
// Provided method
fn is_echoing(&self) -> bool { ... }
}Expand description
Representation of a shell process.
Required Methods
Sourcefn check_is_alive(&mut self) -> Result<()>
fn check_is_alive(&mut self) -> Result<()>
Checks if the process is alive.
Errors
Returns an error if the process is not alive. Should include debug details if possible (e.g., the exit status of the process).
Provided Methods
Sourcefn is_echoing(&self) -> bool
fn is_echoing(&self) -> bool
Returns true if the input commands are echoed back to the output.
The default implementation returns false.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ShellProcess for Child
impl ShellProcess for Child
Implementors
impl ShellProcess for PtyShell
Available on crate feature
portable-pty only.